<?php

class Event
{
	protected $data = array();
	protected $name = '';
	private   $referenceFields = array('event.after', 'event.image',
					'transportation.section', 
					'nearby.lodging', 
					'nearby.food', 
					'images.image', 
					'nearby.thing');

	public function Event($desc, $name='')
	{
		$this->name = $name;
		$this->_loadData($desc);
	}

	public function getName()
	{
		return $this->name;
	}

	private function _loadData($array)
	{
		$section = '';
		foreach($array as $line)
		{
			$line = trim($line);
			if($line=='') continue;
			switch(substr($line, 0, 1))
			{
				case '#':
				case ';':
					continue;
				case '[':
					$len = strlen($line);
					if(']'==substr($line,$len-1,1))
					{
						$section=substr($line,1,$len-2);
					}
					else
					{
						$section=substr($line,1,$len-1);
					}
					$this->data[$section] = array();
					$this->data[$section]['internal']=$section;
					break;
				default: 
					$this->_processLine($section, $line);
			}
		}
	}
	private function _processLine($section, $line)
	{
		list($name, $value) = split(':', $line, 2);
		if($section == "links")
		{
			list($url, $lname) = split("\ ", $value, 2);
			$value = array('url' => $url, 'text' => $lname);
			if(!isset($this->data[$section][$name]))
			{
				$this->data[$section][$name] = array();
			}
		}

		if(isset( $this->data[$section][$name] ) )
		{
			if( is_array( $this->data[$section][$name] ) )
			{
				$this->data[$section][$name][] = $value;
			}
			else
			{
				$x = $this->data[$section][$name];
				$this->data[$section][$name]   = array();
				$this->data[$section][$name][] = $x;
				$this->data[$section][$name][] = $value;
			}
		}
		else
		{
			$this->data[$section][$name] = $value;
		}
		
	}

	#
	# $s is a string such as "section.name"
	#
	public function getEValue($s, $default='')
	{
		$arr = split("\.", $s, 2);
		if( !(is_array($arr) && sizeof($arr) >=2 ) )
		{
			$a = $s; $b= false;
		} else list($a, $b) = $arr;
		if($a == '' || $a == '*')
		{
			// probably the wrong spot for this
			$a = $GLOBALS['PAGE']['label'];
		}
		return $this->getValue($a, $b, $default);
	}

	public function getSectionNames($section)
	{
		if(!(isset($this->data[$section])) )
		{
			return array();
		}
		return array_keys($this->data[$section]);
	}

	public function getValue($section, $name, $default='')
	{
		$rval = $this->getSpecialReturn($section, $name);
		if($rval) return $rval;
		return $this->getRawValue($section, $name, $default);	
	}


	public function getRawValue($section, $name, $default='')
	{	
		if(!(isset($this->data[$section]) && isset($this->data[$section][$name])))
		{
			return $default;
		}
		$rval = $this->data[$section][$name];
		return $rval;
	}

	protected function doSpecialValueMethod ($section, $name)
	{
		$sections = explode('.', $name, 2);
		if(sizeof($sections) > 1)
		{
			if($sections[0] == 'has' || $sections[0] == 'nhas')
			{
				$test =  $this->getValue($section, $sections[1]);
				if(sizeof($test) && $test[0]) return $sections[0] == 'has';
			}
		}
		return false;
	}

	protected function getSpecialReturn($section, $name)
	{
		// check if this is a special method
		$rval = $this->doSpecialValueMethod ($section, $name);
		if($rval)
		{
			return $rval;
		}
		//// 
		if(in_array("${section}.${name}", $this->referenceFields))
		{
			$value = $this->getRawValue($section, $name);
			$rval = array();
			if(!is_array($value))
			{
				if( isset($this->data[$value]) ) $rval[$value] = $this->data[$value];
			}
			else
			{
				foreach($value as $v)
				{
					$rval[$v] = $this->data[$v];
				}
			}
			return $rval;
		}
		if($section == 'event')
		{
			if($name == 'fancydate')
			{
				$value = $this->getRawValue($section, 'time');
				return date("l, F jS, Y", $value);
			}
			if($name == 'fulldate')
			{
				$value = $this->getRawValue($section, 'time');
				return date("r", $value);
			}
			if($name == 'internal')
			{
				return $this->name;
			}
		}
		if($section == 'sys') # should we move this?
		{
			if($name == 'base')
			{
				return $GLOBALS['MYPATH'];
			}
			if($name == 'path')
			{
				return $_SERVER['REQUEST_URI'];
			}
		}
		return false;
	}

}


?>
